---
title: Problem Set 42
subtitle: General Knowledge Quiz
language: en
typesetting:
  paragraph:
    indent: none
    spacing: 1.1em
press:
  paper:
    margin:
      top: 12mm
      left: 2.4cm
      right: 2.4cm
      bottom: 2.4cm
    marks: false
exam:
  course: Geography 101
  titlepage: minimal
---
# Geography Quiz { points=5 }

## -

What is the capital of France?

- [ ] Berlin
- [ ] Madrid
- [x] Paris
- [ ] Rome
- [ ] Lisbon

## -

Which country is not part of the United Kingdom?

- [ ] England
- [ ] Scotland
- [ ] Wales
- [ ] Northern Ireland
- [x] Ireland
- [ ] Manxland

## -

The longest river in the world is the:

- [ ] Amazon River
- [ ] Yangtze River
- [ ] Mississippi River
- [ ] Congo River
- [ ] Mekong River
- [ ] Ganges River
- [x] Nile River

## -

The longest city name in the United Kingdom is:

- [ ] Taumatawhakatangihangakoauauotamateaturipukaka
- [ ] Chargoggagoggmanchauggagoggchaubunagungamaugg
- [x] Llanfairpwllgwyngyllgogerychwyrndrobwllllantysiliogogogoch
- [ ] Pekwachnamaykoskwaskwaypinwanik
- [ ] Azpilicuetagaraycosaroyarenberecolarrea

## -

Which sea is the most saline?

- [ ] Red Sea
- [ ] Mediterranean Sea
- [ ] Caribbean Sea
- [x] Dead Sea
- [ ] Baltic Sea
- [ ] Black Sea

## -

Name each continent:

!!! solution { lines=2 }

    Africa, Antarctica, Asia, Europe, North America, Australia

## -

Shakespeare most knownly citation is:

> To be, or not [to be], that is the [question].
